///	\file	strutil.cpp
///	\brief	strutil.cpp
//#include <sstream>
#include <iomanip>
#include <math.h>
#include <ctype.h>

#include "strutil.h"

using namespace std;

///	\brief	글를 소문자로 만들다.
///	\param	p	소문자로 만들 글
///	\return	소문자로 만들어질 글
string strutil::tolower(const string &p)
{
	string r;
	for(string::const_iterator i = p.begin(); i!=p.end(); i++)
	{
		if ('A' <= *i && *i <= 'Z') r += *i-'A'+'a';	
		else r += *i;
	}
	return r;
}

/// \brief	필요 없는 문자를 제거한다.
///	\param	p	문자열
///	\return	공백, 엔터등을 제거한 문자열 알맹이
string strutil::chop(const string &p)
{
	string::size_type f = p.find_first_not_of(" \n\r");
	string::size_type r = p.find_last_not_of(" \n\r");
	
	if (f == string::npos || r== string::npos) return "";
	
	return p.substr(f, r-f+1);
}

/// \brief	p문자열에서 위치 f, r 사이의 문자열을 반환한다.
///	\param	p		문자열
///	\param	f		반환할 문자의 시작 위치
///	\param	r		반환할 문자의 끝위치
string strutil::getbetween(const string &p, const char f, const char r)
{
	string::size_type s = p.find_first_of(f);
	if (s == string::npos) return "";
	string::size_type s2 = p.find_first_of(r, s+1);
	if (s2 == string::npos) return "";	
	
	return p.substr(s+1 , s2-s-1);	
}

///	\brief	해당되는 글자를 다른 글자로 바꾼다.
///	\param	p		글자를 바꿀 대상 전체
///	\param	find	바꿀 대상 문자
///	\param	replace	바꿀 문자
///	\return	바꾸어진 글
string strutil::replace(const string &p, const char*find, const char*replace)
{
	//  01234567890123456789012
	// "the great great bassist" "great" "brother"	
	string arg;
	
	string::size_type t = 0;
	string::size_type t2= p.find(find);
	
	string::size_type len = strlen(find);
	
	while(t2 != string::npos)
	{
		arg += p.substr(t, t2-t);
		arg += replace;
		
		t = t2 + len;
		t2 = p.find(find, t);
	}
	
	arg += p.substr(t);
	
	return arg;
}

///	\brief	숫자를 문자로 바꾸어준다.
///	\param	number	문자로 바꿀 숫자
///	\return	문자화 된 숫자
string strutil::toregular(unsigned int number)
{
	unsigned int n=1, p=1;
	string str;	
	str.reserve(10);
			
	while(number/10 >= p) {p*=10; n+=1;}		
	
	while (n)
	{
		str += '0' + number / p;
		
		number %= p;
		p /= 10;
		n--;
		
		if (n!=0 && n%3==0) str += ',';	
	}
	
	return str;
}

/// @brief	string에 slash를 추가하는 함수
///
/// 파일이름중에서 특수문자가(예 공백이나 () & *등..을 '\ ' '\ ('로 바꾸어
/// 주는함수
///
/// @param &p
/// @return 
string strutil::addslash(const string &p)
{
	//  t
	// 01234
	// jones
	string arg;
	
	string::size_type t  = 0,
					  t2 = p.find_first_of(" ()&*?$'\"\\\0");
	
	while(t2 != string::npos)
	{
		arg.append(p, t, t2-t);
		arg += '\\';
		arg += p[t2];		
		t = t2 + 1;
		t2 = p.find_first_of(" ()&*?$'\"\\\0", t);
	}	
	arg.append(p, t, p.length()-t);
	
	return arg;			
}

