///	@file	panel_cmd.cpp
///	@brief	panel_cmd.cpp
#include <ncurses.h>
#include <sys/stat.h>

#include <string>
#include <vector>

#include "mls.h"
#include "panel.h"
#include "strutil.h"
#include "dialog.h"
#include "conf.h"
#include "commandimp.h"
#include "StringTokenizer.h"

using namespace std;
using namespace strutil;
using namespace MLS;

void MLS::CommandImp::Edit()
{
	Run(e_tConf.extern_editor + ' ' + addslash(panel->GetCurrentFile().name));
}

void MLS::CommandImp::View()
{
	Run(e_tConf.extern_viewer + ' ' + addslash(panel->GetCurrentFile().name));
}

///	@brief	모든 커맨드 메시지를 관리
///	@param	p	실행 시킬 명령어
///	@return		명령어 실행 결과
int MLS::CommandImp::ParseAndRun(const string &p)
{
	bool	bFlag  = false, 
		 	bPause = false,
		 	bParam = false,
		 	bMcd   = false ,
		 	bConfirm = false;
	
	File 	rf = panel->GetCurrentFile();
	string 	arg;

	// 파싱
	for (string::const_iterator i = p.begin(); i!= p.end(); i++)
	{
		if (*i == '%')
		{
			bFlag = true;
			continue;
		}
		
		if (bFlag)
		{
			switch(*i)
			{
			// 파일을 리턴해줌
			case '1':			
			case 'F':
				arg += addslash(rf.name);
				break;
				
			case 'N':
			{
				if (rf.name[0]=='.') return 0;
				
				string::size_type p = rf.name.rfind('.');
				
				if (p!=string::npos)
					arg += addslash(rf.name.substr(0, p-1));
				else
					arg += addslash(rf.name);
				break;
			}			
			
			case 'E':
				if (rf.ext().empty()) return 0;
				arg += addslash(rf.ext());
				
				break;
				
			case 'W':
				bPause = true;
				break;
				
			case '%':
				arg += '%';
				break;
				
			case 'S':
			{
				Selection tSelection = panel->GetSelection();
				
				if (tSelection.Size() == 0) return 0;				
				bool first = true;				
			
				for (int t = 0; t< tSelection.Size(); t++)
				{
					if (first) first= false;
					else arg += ' ';
					
					arg += addslash(tSelection[t]);
				}
				break;
			}
			
			case 's':
			{
				Selection tSelection = panel->GetSelection();
				
				if (!tSelection.Size() == 0)
				{
					bool first = true;					
				
					for (int t = 0; t< tSelection.Size(); t++)
					{
						if (first) first= false;
						else arg += ' ';
					
						arg += addslash(tSelection[t]);
					}
				}
				else 
				{
					if (rf.name == "..") return 0;
					arg += addslash(rf.name);
				}
				
				break;
			}
			
			case 'd':
			
				arg += addslash(panel->GetCurrentPath());
				break;		
			
			case 'D':
				bMcd = true;				
				break;
			
			case 'P':
				bParam= true;
			
				break;
				
			case 'H':
				arg += addslash(e_tConf.home);
				
				break;
				
			case 'Q':
				bConfirm = true;
				break;
				
			default:
				break;
			}
			
			bFlag = false;
			continue;
		}
		else arg += *i;
	}
	
	if (bMcd)
	{
		MLS::DirMcd mcd;
		mcd.setCur(panel->GetCurrentPath());
		if (!mcd.proc())
            return 0;
		arg += addslash(mcd.getCur());
	}
	
	if (bParam)	if (InputBox("Edit Parameter", arg)<0) return 0;
		
	if (bConfirm)
		if (YNBox("Do you want to run this operation?", YN_N) != YN_Y) return 0;
		
	// 실행
	int nRt = Run(arg, bPause);
	
	panel->Refresh();
	return nRt;
}
